@@ -37,10 +37,17 @@ type ServerApp = PendingConnection -> IO ()
 
 
 --------------------------------------------------------------------------------
--- | Provides a simple server. This function blocks forever. Note that this
--- is merely provided for quick-and-dirty standalone applications, for real
+-- | Provides a simple server. This function blocks forever.  Note that this
+-- is merely provided for quick-and-dirty or internal applications, but for real
 -- applications, you should use a real server.
 --
+-- For example:
+--
+-- * Performance is reasonable under load, but:
+-- * No protection against DoS attacks is provided.
+-- * No logging is performed.
+-- * ...
+--
 -- Glue for using this package with real servers is provided by:
 --
 -- * <https://hackage.haskell.org/package/wai-websockets>
@@ -59,13 +66,13 @@ runServerWith :: String -> Int -> ConnectionOptions -> ServerApp -> IO ()
 runServerWith host port opts app = S.withSocketsDo $
   bracket
   (makeListenSocket host port)
-  S.sClose
+  S.close
   (\sock ->
     mask_ $ forever $ do
       allowInterrupt
       (conn, _) <- S.accept sock
       void $ forkIOWithUnmask $ \unmask ->
-        finally (unmask $ runApp conn opts app) (S.sClose conn)
+        finally (unmask $ runApp conn opts app) (S.close conn)
     )
 
 
@@ -75,17 +82,20 @@ runServerWith host port opts app = S.withSocketsDo $
 -- connections. Should only be used for a quick and dirty solution! Should be
 -- preceded by the call 'Network.Socket.withSocketsDo'.
 makeListenSocket :: String -> Int -> IO Socket
-makeListenSocket host port = bracketOnError
-    (S.socket S.AF_INET S.Stream S.defaultProtocol)
-    S.sClose
+makeListenSocket host port = do
+  addr:_ <- S.getAddrInfo (Just hints) (Just host) (Just (show port))
+  bracketOnError
+    (S.socket (S.addrFamily addr) S.Stream S.defaultProtocol)
+    S.close
     (\sock -> do
         _     <- S.setSocketOption sock S.ReuseAddr 1
         _     <- S.setSocketOption sock S.NoDelay   1
-        host' <- S.inet_addr host
-        S.bindSocket sock (S.SockAddrInet (fromIntegral port) host')
+        S.bind sock (S.addrAddress addr)
         S.listen sock 5
         return sock
         )
+  where
+    hints = S.defaultHints { S.addrSocketType = S.Stream }
 
 
 --------------------------------------------------------------------------------
